pub struct DefaultUser {
pub display_name: String,
pub is_bot: bool,
}Expand description
The SimpleX user profile used to initialise the chat instance.
Security
The display_name field is injected into a SimpleX CLI command of the form /create {kind} '{display_name}'. It is intended to be a short, fixed, ASCII identifier chosen by the
application author, do not supply a user-input here to avoid command injections like:
“User’Name”(creates a user named “User” with bio=“Name”)
Fields
display_name: Stringis_bot: boolImplementations